
/**
 * @overview Defines the default client-side authentication provider class which
 * communicates with a remote server running `stout-auth/server/AuthProvider`
 * authentication provider.
 *
 * @module stout-auth/provider/ClientAuthProvider
 */

(function() {
  var AuthProvider, ClientAuthProvider,
    extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
    hasProp = {}.hasOwnProperty;

  AuthProvider = require('./AuthProvider');


  /**
   * The AuthProvider class provides client-side authentication services for
   * web applications running in the browser. It's designed to communicates with a
   * remote server running the `stout-auth/server/AuthProvider` class for seamless
   * authentication functions between a client and server.
   *
   * @exports stout-auth/provider/ClientAuthProvider
   * @extends stout-auth/provider/AuthProvider
   * @constructor
   */

  module.exports = ClientAuthProvider = (function(superClass) {
    extend(ClientAuthProvider, superClass);

    function ClientAuthProvider() {
      ClientAuthProvider.__super__.constructor.apply(this, arguments);
    }


    /**
     * Signs-in the user with the server.
     *
     * @param {object} [request] - Sign-in request.
     *
     * @param {function} fulfill - Successful sign-in callback.
     *
     * @param {function} reject - Failed sign-in callback.
     * request.
     *
     * @method signin
     * @memberof stout-auth/server/AuthProvider#
     */

    ClientAuthProvider.prototype.signin = function(fulfill, reject, username, password) {};


    /**
     * Signs-out the user with the server.
     *
     * @param {object} [request] - Sign-out request.
     *
     * @param {function} fulfill - Successful sign-in callback.
     *
     * @param {function} reject - Failed sign-in callback.
     *
     * @method signout
     * @memberof stout-auth/server/AuthProvider#
     */

    ClientAuthProvider.prototype.signout = function(fulfill, reject) {};


    /**
     * Registers a new user account.
     *
     * @param {object} [request] - Registration request.
     *
     * @param {function} fulfill - Successful registration callback.
     *
     * @param {function} reject - Failed registration callback.
     *
     * @method register
     * @memberof stout-auth/server/AuthProvider#
     */

    ClientAuthProvider.prototype.register = function(fulfill, reject, username, password, metadata) {};


    /**
     * Verifies the user's credentials with the server.
     *
     * @param {object} [request] - Credentials verification request.
     *
     * @param {function} fulfill - Successful verification callback.
     *
     * @param {function} reject - Failed verification callback.
     *
     * @method verify
     * @memberof stout-auth/server/AuthProvider#
     */

    ClientAuthProvider.prototype.verify = function(fulfill, reject, username, password) {};


    /**
     * Requests a password reset.
     *
     * @param {object} [request] - Password reset request.
     *
     * @param {function} fulfill - Successful password reset callback.
     *
     * @param {function} reject - Failed password reset callback.
     *
     * @method resetPassword
     * @memberof stout-auth/server/AuthProvider#
     */

    ClientAuthProvider.prototype.resetPassword = function(fulfill, reject, currentPassword) {};

    return ClientAuthProvider;

  })(AuthProvider);

}).call(this);

//# sourceMappingURL=ClientAuthService.js.map
