###*
# @overview Defines the Password model, a simple model which stores a user's
# password verifier, as well as verifier version
#
# @module stout-auth/model/Password
###
Model = require 'stout-orm/model/Model'



###*
# The Password model stores a password verifier, as well as the algorithm and
# version used to generate that password.
#
# @exports stout-auth/model/Password
# @extends stout-orm/model/model
# @constructor
###
module.exports = Model.define 'Password',

  ###*
  # The provider name used to retrieve and store password verifiers. The
  # actual provider class used is determined at app boot time.
  #
  # @member {mixed} provider
  # @memberof stout-auth/model/Password
  ###
  provider: 'PasswordProvider'


  ###*
  # Each verifier is associated with one user. The actual User class used
  # is determined at app boot time. This creates a foreign key property
  # `__user_fk` pointing to the associate user on the Password instance.
  #
  # @member {mixed} belongsTo
  # @memberof stout-auth/model/Password
  ###
  belongsTo: 'User'


  properties:

    ###*
    # The algorithm name used to generate the password verifier.
    #
    # @member {string} algorithm
    # @memberof stout-auth/model/Password#
    ###
    algorithm:
      type: 'string'
      required: true


    ###*
    # The algorithm version used.
    #
    # @member {number} version
    # @memberof stout-auth/model/Password#
    ###
    version:
      type: 'number'
      required: true


    ###*
    # The password verifier.
    #
    # @member {string} verifier
    # @memberof stout-auth/model/Password#
    ###
    verifier:
      type: 'string'
      required: true
