###*
# @overview Defines the PasswordReset model, a model which represents a
# password reset request.
#
# @module stout-auth/model/PasswordReset
###
Model = require 'stout-orm/model/Model'



###*
# The PasswordReset model represents a password reset request, it's request
# code, and an expiration date/time.
#
# @exports stout-auth/model/PasswordReset
# @extends stout-orm/model/model
# @constructor
###
module.exports = Model.define 'PasswordReset',

  ###*
  # The provider name used to retrieve and store password verifiers. The
  # actual provider class used is determined at app boot time.
  #
  # @member {mixed} provider
  # @memberof stout-auth/model/PasswordReset
  ###
  provider: 'PasswordResetProvider'


  ###*
  # Each password reset request is associated with one user. The actual
  # User class used is determined at app boot time.
  #
  # @member {mixed} hasOne
  # @memberof stout-auth/model/PasswordReset
  ###
  hasOne: 'User'


  properties:

    ###*
    # The password reset token.
    #
    # @member {string} token
    # @memberof stout-auth/model/PasswordReset#
    ###
    token:
      type: 'string'
      required: true


    ###*
    # The expiration timestamp.
    #
    # @member {string} expires
    # @memberof stout-auth/model/PasswordReset#
    ###
    expires:
      type: 'number'
      required: true


  ###*
  # Checks if this password reset request is expired.
  #
  # @returns {boolean} True if this reset is expired, otherwise false.
  #
  # @method expired
  # @memberof stout-auth/model/PasswordReset#
  ###
  expired: ->
    @expires >= Date.now()
