###*
# @overview Defines the Role model.
#
# @module stout-auth/model/Role
###
Model = require 'stout-orm/model/Model'


###*
# The Role model defines a set of permissions. Users may be assigned a role,
# which grants them the permissions defined by the role. Roles are dynamic and
# can be created at run time and are stored in a datastore.
#
# @exports stout-auth/model/Role
# @extends stout-orm/model/Model
# @constructor
###
module.exports = Model.define 'Role',

  properties:

    ###*
    # The role name.
    #
    # @member {string} name
    # @memberof stout-auth/model/Role#
    ###
    name:
      type: 'string'
      required: true

    ###*
    # Set of permissions for this role.
    #
    # @member {string[]} permissions
    # @memberof stout-auth/model/Role#
    ###
    permissions:
      default: []
      type: 'array'


  ###*
  # The provider name used to retrieve and store Role models.
  #
  # @member {mixed} provider
  # @memberof stout-auth/model/Role#
  ###
  provider: 'RoleProvider'


  ###*
  # There's a many-to-many type relationship between users and roles. Each role
  # may belong to many users and each user may have many roles.
  #
  # @member {mixed} hasMany
  # @memberof stout-auth/model/Role#
  ###
  hasMany: 'User'
