###*
# @overview Defines the common server/client abstract auth provider.
#
# @module stout-auth/service/AuthService
###
defaults  = require 'lodash/defaults'
HasLogger = require 'stout-core/log/HasLogger'
Service   = require 'stout-core/service/Service'


###*
# Fired when a user sign-in request is sent to the server.
#
# @event "signin:request"
# @type stout-core/event/Event
###

###*
# Fired when a user sign-in is successful.
#
# @event "signin:success"
# @type stout-core/event/Event
###

###*
# Fired when a sign-in failed.
#
# @event "signin:error"
# @type stout-core/event/Event
###

###*
# Fired when a sign-out request is sent to the server.
#
# @event "signout:request"
# @type stout-core/event/Event
###

###*
# Fired when a sign-out is successful.
#
# @event "signout:success"
# @type stout-core/event/Event
###

###*
# Fired when a sign-out failed.
#
# @event "signout:error"
# @type stout-core/event/Event
###

###*
# Fired when a registration request is sent to the server.
#
# @event "register:request"
# @type stout-core/event/Event
###

###*
# Fired when a registration request is successful.
#
# @event "register:success"
# @type stout-core/event/Event
###

###*
# Fired when a registration request fails.
#
# @event "register:error"
# @type stout-core/event/Event
###

###*
# Fired when a verification request is sent to the server.
#
# @event "verify:request"
# @type stout-core/event/Event
###

###*
# Fired when a verification request is successful.
#
# @event "verify:success"
# @type stout-core/event/Event
###

###*
# Fired when a verification request fails.
#
# @event "verify:error"
# @type stout-core/event/Event
###

###*
# Fired when a password reset request is sent to the server.
#
# @event "reset-password:request"
# @type stout-core/event/Event
###

###*
# Fired when a password reset is successful.
#
# @event "reset-password:success"
# @type stout-core/event/Event
###

###*
# Fired when a password reset fails.
#
# @event "reset-password:error"
# @type stout-core/event/Event
###

###*
# Fired on a password change request.
#
# @event "change-password:request"
# @type stout-core/event/Event
###

###*
# Fired when a password change is successful.
#
# @event "change-password:success"
# @type stout-core/event/Event
###

###*
# Fired when a password change fails.
#
# @event "change-password:error"
# @type stout-core/event/Event
###



module.exports = AuthService = Service.extend 'AuthService',

  constructor: (init, args...) ->
    init = defaults init,
      name: 'auth'
    Service.prototype.constructor.call @, init, args...
    @registerEvents 'signin signout register verify reset-password
    change-password'
    return


AuthService.useTrait HasLogger, null, 'auth'
