assert              = require('chai').assert
PermissionsProvider = require '../../../provider/PermissionsProvider'
Provider            = require 'stout-core/provider/Provider'
sinon               = require 'sinon'



describe 'provider/PermissionsProvider', ->
  provider = null

  beforeEach ->
    provider = new PermissionsProvider


  specify 'the $bootOrder is less than the default provider boot order', ->
    assert.isBelow PermissionsProvider.$bootOrder, Provider.$bootOrder



  describe '#defineAction()', ->

    it 'returns a function if passed an array', ->
      assert.isFunction provider.defineAction('test action', ['a', 'b'])

    it 'adds a passed function to the set of actions', ->
      f = ->
      provider.defineAction 'test action', f
      assert.equal f, provider.getAction('test action')

    specify 'duplicate actions override the one previously defined', ->
      f = ->
      q = ->
      provider.defineAction 'test action', q
      assert.equal q, provider.getAction('test action')
      provider.defineAction 'test action', f
      assert.equal f, provider.getAction('test action')


    describe 'dynamically created action function', ->
      fn = null

      beforeEach ->
        fn = provider.defineAction('test action', ['b', 'x', 'c'])

      it 'returns `true` if all the required permissions are passed', ->
        assert.isTrue fn(['b', 'c', 'x'])

      it 'gracefully handles duplicate permissions', ->
        assert.isTrue fn(['b', 'c', 'x', 'x', 'c', 'c', 'b'])

      it 'returns `true` if extra permissions are passed', ->
        assert.isTrue fn(['b', 'c', 'x', 'a', 'w'])

      it 'returns `false` if not all the require permissions are passed', ->
        assert.isFalse fn(['b', 'c'])
        assert.isFalse fn(['x', 'c'])
        assert.isFalse fn([])
        assert.isFalse fn(['x', 'b', 'a', 'w'])



  describe '#define()', ->

    it 'throws an err if the permission is already defined', ->
      fn = -> provider.define 'a'
      fn()
      assert.throws fn



  describe '#defined()', ->

    beforeEach ->
      provider.define 'a'
      provider.define 'b'
      provider.define 'c'

    it 'returns `true` if the passed permission is defined', ->
      assert.isTrue provider.defined('a')
      assert.isTrue provider.defined('b')
      assert.isTrue provider.defined('c')

    it 'returns `false` if the passed permission is not defined', ->
      assert.isFalse provider.defined('f')
      assert.isFalse provider.defined('q')



  describe '#testAction()', ->

    it 'tests the passed permissions against the specified action', ->
      provider.defineAction 'test', ['a', 'b']
      assert.isTrue provider.testAction('test', ['a', 'b', 'c'])
      assert.isFalse provider.testAction('test', ['b', 'c'])
