assert             = require('chai').assert
ClientAuthProvider = require '../../../client/AuthProvider'
ServerAuthProvider = require '../../../server/AuthProvider'
sinon              = require 'sinon'


for name, AuthProvider of {
'client': ClientAuthProvider, 'server': ServerAuthProvider}
  ((AuthProvider) ->
    describe "#{name}/AuthProvider", ->

      auth = s1 = null

      beforeEach ->
        auth = new AuthProvider

      for event in ['signin', 'signout', 'register', 'verify', 'reset-password']
        ((event) ->
          it "the \"#{event}\" event is registered", ->
            assert.isTrue auth.eventRegistered(event),
              "The \"#{event}\" event is not registered."
        )(event)

      for method in ['signin', 'signout', 'register', 'verify', 'resetPassword']
        ((method) ->
          it "has a ##{method}() method", ->
            assert.isFunction auth[method],
              "The ##{method}() method does not exist."
        )(method)

      for service in ['signin', 'signout', 'register', 'verify', 'reset']
        ((service) ->
          it "provides the \"#{service}\" service", ->
            assert.isTrue auth.eventRegistered(event),
              "The #{service} service is not exposed."
        )(service)


      describe 'signin service', ->

        it 'calls #signin()', ->
          assert.fail()

        it 'fires "signin:request" when a signin request is sent', ->
          assert.fail()

        it 'fires "signin:success" when a signin request succeeds', ->
          assert.fail()

        it 'fires "signin:fail" when a signin request fails', ->
          assert.fail()

        it 'fires "signin:rate-limit" when signin requests are rate limited', ->
          assert.fail()


      describe 'signout service', ->

        it 'calls #signout()', ->
          assert.fail()

        it 'fires "signout:request" when a signout request is sent', ->
          assert.fail()

        it 'fires "signout:success" when a signout request succeeds', ->
          assert.fail()

        it 'fires "signout:fail" when a signout request fails', ->
          assert.fail()


      describe 'register service', ->

        it 'calls #register()', ->
          assert.fail()

        it 'fires "register:request" when a registration request is sent', ->
          assert.fail()

        it 'fires "register:success" when a registration request succeeds', ->
          assert.fail()

        it 'fires "register:fail" when a registration request fails', ->
          assert.fail()


      describe 'verify service', ->

        it 'calls #verify()', ->
          assert.fail()

        it 'fires "verify:request" when a verification request is sent', ->
          assert.fail()

        it 'fires "verify:success" when a verification request succeeds', ->
          assert.fail()

        it 'fires "verify:fail" when a verification request fails', ->
          assert.fail()


      describe 'reset service', ->

        it 'calls #resetPassword()', ->
          assert.fail()

        it 'fires "reset-password:request" when a password reset is requested',
        ->
          assert.fail()

        it 'fires "reset-password:success" when a password reset is completed',
        ->
          assert.fail()

        it 'fires "reset-password:fail" when a password reset fails', ->
          assert.fail()

  )(AuthProvider)
